"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.configureDeployCommand = void 0;
const fs_extra_1 = __importDefault(require("fs-extra"));
const path_1 = __importDefault(require("path"));
const cli_progress_1 = __importDefault(require("cli-progress"));
const cloud_1 = require("@cubejs-backend/cloud");
const config_1 = require("../config");
const utils_1 = require("../utils");
const deploy = async ({ directory, auth, uploadEnv, replaceEnv, token }) => {
    if (!(await fs_extra_1.default.pathExists(path_1.default.join(process.cwd(), 'node_modules', '@cubejs-backend/server-core')))) {
        await (0, utils_1.displayError)('@cubejs-backend/server-core dependency not found. Please run deploy command from project root directory and ensure npm install has been run.');
    }
    const config = new config_1.ConfigCli();
    if (token) {
        await config.addAuthToken(token);
        await (0, utils_1.event)({ event: 'Cube Cloud CLI Authenticate' });
        console.log('Token successfully added!');
    }
    const bar = new cli_progress_1.default.SingleBar({
        format: '- Uploading files | {bar} | {percentage}% || {value} / {total} | {file}',
        barCompleteChar: '\u2588',
        barIncompleteChar: '\u2591',
        hideCursor: true
    });
    const envVariables = uploadEnv || replaceEnv ? await config.envFile(`${directory}/.env`) : {};
    const cubeCloudClient = new cloud_1.CubeCloudClient(auth || (await config.deployAuthForCurrentDir()));
    const deployController = new cloud_1.DeployController(cubeCloudClient, { envVariables, replaceEnv }, {
        onStart: async (deploymentName, files) => {
            await (0, utils_1.logStage)(`Deploying ${deploymentName}...`, 'Cube Cloud CLI Deploy');
            bar.start(files.length, 0, {
                file: ''
            });
        },
        onUpdate: (i, { file }) => {
            bar.update(i, { file });
        },
        onUpload: (files) => {
            bar.update(files.length, { file: 'Post processing...' });
        },
        onFinally: () => {
            bar.stop();
        }
    });
    await deployController.deploy(directory);
    await (0, utils_1.logStage)('Done 🎉', 'Cube Cloud CLI Deploy Success');
};
function configureDeployCommand(program) {
    program
        .command('deploy')
        .description('Deploy project to Cube Cloud')
        .option('--upload-env', 'Use .env file to populate environment variables in Cube Cloud. Only set them once during the very first upload for this deployment')
        .option('--replace-env', 'Use .env file to populate environment variables in Cube Cloud. Replace them with new ones during every upload for this deployment')
        .option('--token <token>', 'Add auth token to CubeCloud')
        .option('--directory [path]', 'Specify path to conf directory', './')
        .action((options) => deploy({
        ...options,
        directory: path_1.default.join(process.cwd(), options.directory)
    })
        .catch(e => (0, utils_1.displayError)(e.stack || e)))
        .on('--help', () => {
        console.log('');
        console.log('Examples:');
        console.log('');
        console.log('  $ cubejs deploy');
    });
}
exports.configureDeployCommand = configureDeployCommand;
//# sourceMappingURL=deploy.js.map